summaryrefslogtreecommitdiffstats
path: root/include/hardware_legacy/gscan.h
diff options
context:
space:
mode:
authorPierre Vandwalle <vandwalle@google.com>2015-03-18 13:36:18 -0700
committerPierre Vandwalle <vandwalle@google.com>2015-03-18 19:36:15 -0700
commit08b10f046d538366b30898a76424982679763f88 (patch)
tree0ddae7e4489cdc5cf912f0e3325880d38883037a /include/hardware_legacy/gscan.h
parent0bf6fc2374cdeaaaa5c0706420935e8210382cdd (diff)
downloadhardware_libhardware_legacy-08b10f046d538366b30898a76424982679763f88.zip
hardware_libhardware_legacy-08b10f046d538366b30898a76424982679763f88.tar.gz
hardware_libhardware_legacy-08b10f046d538366b30898a76424982679763f88.tar.bz2
fix to hal interface
Change-Id: I32f3e22fd19e79669ab8b117acd51352d132dbc3
Diffstat (limited to 'include/hardware_legacy/gscan.h')
-rw-r--r--include/hardware_legacy/gscan.h28
1 files changed, 21 insertions, 7 deletions
diff --git a/include/hardware_legacy/gscan.h b/include/hardware_legacy/gscan.h
index 3cc8050..af74346 100644
--- a/include/hardware_legacy/gscan.h
+++ b/include/hardware_legacy/gscan.h
@@ -22,6 +22,7 @@ const unsigned MAX_HOTLIST_APS = 128;
const unsigned MAX_SIGNIFICANT_CHANGE_APS = 64;
const unsigned MAX_PNO_SSID = 128;
const unsigned MAX_HOTLIST_SSID = 8;
+const unsigned MAX_BLACKLIST_BSSID = 16;
wifi_error wifi_get_valid_channels(wifi_interface_handle handle,
int band, int max_channels, wifi_channel *channels, int *num_channels);
@@ -33,7 +34,8 @@ typedef struct {
int max_rssi_sample_size; // number of RSSI samples used for averaging RSSI
int max_scan_reporting_threshold; // max possible report_threshold as described
// in wifi_scan_cmd_params
- int max_hotlist_aps; // maximum number of entries for hotlist APs
+ int max_hotlist_bssids; // maximum number of entries for hotlist BSSIDs
+ int max_hotlist_ssids; // maximum number of entries for hotlist SSIDs
int max_significant_wifi_change_aps; // maximum number of entries for
// significant wifi change APs
int max_bssid_history_entries; // number of BSSID/RSSI entries that device can hold
@@ -172,7 +174,7 @@ typedef struct {
typedef struct {
int lost_ap_sample_size;
- int num_ap; // number of hotlist APs
+ int num_bssid; // number of hotlist APs
ap_threshold_param ap[MAX_HOTLIST_APS]; // hotlist APs
} wifi_bssid_hotlist_params;
@@ -200,8 +202,8 @@ typedef struct {
typedef struct {
int lost_ssid_sample_size;
- int num_ap; // number of hotlist APs
- ssid_threshold_param ssid[MAX_HOTLIST_APS]; // hotlist APs
+ int num_ssid; // number of hotlist SSIDs
+ ssid_threshold_param ssid[MAX_HOTLIST_SSID]; // hotlist SSIDs
} wifi_ssid_hotlist_params;
@@ -212,6 +214,18 @@ wifi_error wifi_set_ssid_hotlist(wifi_request_id id, wifi_interface_handle iface
/* Clear the SSID Hotlist */
wifi_error wifi_reset_ssid_hotlist(wifi_request_id id, wifi_interface_handle iface);
+
+/* BSSID blacklist */
+typedef struct {
+ int num_bssid; // number of blacklisted BSSIDs
+ mac_addr bssids[MAX_BLACKLIST_BSSID]; // blacklisted BSSIDs
+} wifi_bssid_params;
+
+/* Set the BSSID blacklist */
+wifi_error wifi_set_bssid_blacklist(wifi_request_id id, wifi_interface_handle iface,
+ wifi_bssid_params params);
+
+
/* Significant wifi change */
typedef struct {
mac_addr bssid; // BSSID
@@ -234,7 +248,7 @@ typedef struct {
int rssi_sample_size; // number of samples for averaging RSSI
int lost_ap_sample_size; // number of samples to confirm AP loss
int min_breaching; // number of APs breaching threshold
- int num_ap; // max 64
+ int num_bssid; // max 64
ap_threshold_param ap[MAX_SIGNIFICANT_CHANGE_APS];
} wifi_significant_change_params;
@@ -377,7 +391,7 @@ typedef struct {
// Hysteresis: ensuring the currently associated BSSID is favored
// so as to prevent ping-pong situations
- int lazy_roam_histeresys; // boost applied to current BSSID
+ int lazy_roam_hysteresis; // boost applied to current BSSID
// Alert mode enable, i.e. configuring when firmware enters alert mode
int alert_roam_rssi_trigger; // RSSI below which "Alert" roam is enabled
@@ -395,7 +409,7 @@ wifi_error wifi_enable_lazy_roam(wifi_request_id id, wifi_interface_handle iface
* Per BSSID preference
*/
typedef struct {
- char bssid[6];
+ mac_addr bssid;
int rssi_modifier; // modifier applied to the RSSI of the BSSID for the purpose of comparing
// it with other roam candidate
} wifi_bssid_preference;